==> xl-react-components-0.16.62.tgz: package/app/xl-react-widget/xl-react-widget-confirmation-dialog/xl-react-widget-confirmation-dialog.js <==
import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';
import R from 'ramda';
import {Modal} from 'react-bootstrap';
import {XlReactWidgetModalDialog} from '../xl-react-widget-modal-dialog/xl-react-widget-modal-dialog';
import {confirmationDialogSkins, getBehavior} from './xl-react-widget-confirmation-dialog-skins';
import './xl-react-widget-confirmation-dialog.less';

export class XlReactWidgetConfirmationDialog extends PureComponent {
    static propTypes = {
        animation: PropTypes.bool,
        buttons: PropTypes.arrayOf(PropTypes.shape({
            action: PropTypes.string.isRequired,
            className: PropTypes.string.isRequired,
            disabled: PropTypes.bool,
            keyCodes: PropTypes.arrayOf(PropTypes.number),
            label: PropTypes.string.isRequired
        })),
        children: PropTypes.element,
        dialogClassName: PropTypes.string,
        onButtonClick: PropTypes.func,
        onCheckboxClick: PropTypes.func,
        show: PropTypes.bool,
        skin: PropTypes.oneOf(R.values(confirmationDialogSkins)),
        title: PropTypes.string
    };

    static defaultProps = {
        animation: false,
        show: false,
        skin: confirmationDialogSkins.DEFAULT
    };

    handleCheck = (value) => {
        this.props.onCheckboxClick(value);
    };

    handleClick = (action) => {
        this.props.onButtonClick(action);
    };

    handleKeyDown = (event) => {
        const actionButton = R.find(
            R.both(
                R.complement(R.propEq('disabled', true)),
                R.pipe(
                    R.prop('keyCodes'),
                    R.defaultTo([]),
                    R.includes(event.keyCode)
                )
            )
        )(this.props.buttons);

        if (actionButton) {
            event.preventDefault();
            this.handleClick(actionButton.action);
        }
    };

    render() {
        const {
            animation,
            children,
            dialogClassName,
            title,
            skin,
            show
        } = this.props;

        const behaviour = getBehavior(skin);

        return <div className="xl-react-widget-confirmation-dialog" onKeyDown={this.handleKeyDown}>
            {show ? <XlReactWidgetModalDialog
                animation={animation}
                dialogClassName={dialogClassName}
                showModal={show}
                title={title}>

                <div className="confirmation-content">
                    {children}
                </div>

                <Modal.Footer>
                    <div className="confirmation-dialog dialog-buttons">
                        {behaviour.renderButtonsLayout(this)}
                    </div>
                </Modal.Footer>
            </XlReactWidgetModalDialog> : null}
        </div>;
    }
}

==> xl-react-components-0.21.12.tgz: package/app/xl-react-widget/xl-react-widget-confirmation-dialog/xl-react-widget-confirmation-dialog.js <==
import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';
import R from 'ramda';
import classNames from 'classnames';
import {Modal} from 'react-bootstrap';
import {XlReactWidgetModalDialog} from '../xl-react-widget-modal-dialog/xl-react-widget-modal-dialog';
import {confirmationDialogSkins, getBehavior} from './xl-react-widget-confirmation-dialog-skins';
import './xl-react-widget-confirmation-dialog.less';

export class XlReactWidgetConfirmationDialog extends PureComponent {
    static propTypes = {
        animation: PropTypes.bool,
        buttons: PropTypes.arrayOf(PropTypes.shape({
            action: PropTypes.string.isRequired,
            className: PropTypes.string.isRequired,
            disabled: PropTypes.bool,
            keyCodes: PropTypes.arrayOf(PropTypes.number),
            label: PropTypes.string.isRequired
        })),
        children: PropTypes.element,
        dialogClassName: PropTypes.string,
        onButtonClick: PropTypes.func,
        onCheckboxClick: PropTypes.func,
        show: PropTypes.bool,
        skin: PropTypes.oneOf(R.values(confirmationDialogSkins)),
        title: PropTypes.string
    };

    static defaultProps = {
        animation: false,
        show: false,
        skin: confirmationDialogSkins.DEFAULT
    };

    handleCheck = (value) => {
        this.props.onCheckboxClick(value);
    };

    handleClick = (action) => {
        this.props.onButtonClick(action);
    };

    handleKeyDown = (event) => {
        const actionButton = R.find(
            R.both(
                R.complement(R.propEq('disabled', true)),
                R.pipe(
                    R.prop('keyCodes'),
                    R.defaultTo([]),
                    R.includes(event.keyCode)
                )
            )
        )(this.props.buttons);

        if (actionButton) {
            event.preventDefault();
            this.handleClick(actionButton.action);
        }
    };

    render() {
        const {
            animation,
            children,
            dialogClassName,
            title,
            skin,
            show
        } = this.props;

        const behaviour = getBehavior(skin);

        const dialogClassNames = classNames('xl-react-widget-confirmation-dialog', 'with-blue-header', dialogClassName);

        return <div onKeyDown={this.handleKeyDown}>
            {show ? <XlReactWidgetModalDialog
                animation={animation}
                dialogClassName={dialogClassNames}
                showModal={show}
                title={title}>

                <div className="confirmation-content">
                    {children}
                </div>

                <Modal.Footer>
                    <div className="confirmation-dialog dialog-buttons">
                        {behaviour.renderButtonsLayout(this)}
                    </div>
                </Modal.Footer>
            </XlReactWidgetModalDialog> : null}
        </div>;
    }
}
